**El Niño pacemaker experimental setup**

Instructions to replicate the strong El Niño simulations presented in the paper "Future climate response to observed strong El Niño analogues", by By Paloma Trascasa-Castro, Yohan Ruprich-Robert and Amanda Maycock.

Please send an email to paloma.trascasa@bsc.es in case you have any question.

The El Niño idealized pacemakers are designed to assess the effect of different background climate states (present and future climates) on El Niño impacts. To do so, we select 3 case studies: the El Niño events of 1982-83, 1997-98 and 2015-16.
We imposed observed SST anomalies on top of the model's own climatology in the past, present and future. We restore the tropical Pacific from latitudes is 10°S - 10°N and longitudes from 130°E - 70°W, with a 10° buffer zone on each side except the eastern margin which coincides with the American continent.

**1. Extract SST anomalies from observations:**

We use observations from the ERSST.v5 dataset (Huang et al. 2017) and compute sea surface temperature (SST) anomalies relative to the period from 1981 to 2010. For each strong El Niño event that we want to simulate, we take 2 whole years of observed SST anomalies:
- January 1982 to December 1983.
- January 1997 to December 1998.
- January 2015 to December 2016.

**2. Convert SST anomalies to ORCA1 grid**

ORCA1 is the ocean grid of EC-Earth3-CC (Döscher et al., 2021)
Because observed SST anomalies need to be added on top of the model's climatology, it is necessary to interpolate observed SST anomalies into ORCA1 grid. To do so, edit the following namelist to use it with the SOSIE interpolation:
`namelist.ERSSTv5_to_ORCA1_tos`

The section "Input characteristics" contains the info about the file you want to interpolate on ORCA1
the section "Horizontal output Grid characteristics" does not be to be changed.

Section "Netcdf output characteristics" can be changed but it just a matter of naming of your output files.
          
Change parameters "cf_in", "cv_in", "cv_t_in" and "cd_out" accordingly to your input file and your output directory.

```
module load GCC/4.9.2
module load netCDF-Fortran/4.2-foss-2015a
./sosie.x -f your_namelist_path/file
```
**3. Calculate seasonal cycle from climatological model values**

Ensemble members took from EC-Earth3-CC's climatological runs: 
- Present: a3bh (fc0), a3bh (fc01), a3o0, a3nm, a3o2, a3o4, a3o1, a3o7, a3o3, a45i
- Future: a3dn, a47n, a47o, a47p, a45r, a47q, a47r, a47s, a47t, a47u

Create a 24-month file with the climatological seasonal cycle (x2) estimated by averaging the 10 ensemble members of the period:

- Present: 2005-2014   
- Future: 2085-2094

Add SST anomalies (already in ORCA grid) to its respective seasonal cycle, and inflate the total field by running the following script on NCL:



_**References**_


Döscher, R., Acosta, M., Alessandri, A., Anthoni, P., Arneth, A., Arsouze, T., ... & Zhang, Q. (2021). The EC-earth3 Earth system model for the climate model intercomparison project 6. Geoscientific Model Development Discussions, 2021, 1-90.


Huang, B., Thorne, P. W., Banzon, V. F., Boyer, T., Chepurin, G., Lawrimore, J. H., ... & Zhang, H. M. (2017). Extended reconstructed sea surface temperature, version 5 (ERSSTv5): upgrades, validations, and intercomparisons. Journal of Climate, 30(20), 8179-8205.


